@@ -10,7 +10,7 @@
  ============================================================================
  Name        : main.c
  Author      : Dart
- Version     : 0.1
+ Version     : 0.3
  Description : Control Panel Applet to customize MicroB useragent.
  ============================================================================
  */
@@ -31,26 +31,92 @@
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <hildon/hildon-note.h>
+#include <string.h>
+#include <hildon/hildon.h>
 
 
 #define RESPONSE_SET 100
 #define RESPONSE_REMOVE 200
+#define RESPONSE_UA 300
 
 void displayresult (GtkWidget *parent, const char *Text)
 {
   GtkWidget *banner;
 
-  /*banner = hildon_banner_show_information (parent, NULL, "toto");
-  hildon_banner_set_timeout (HILDON_BANNER (banner), 9000);
-printf("ta mere2");*/
-
-  banner = hildon_note_new_information(parent, Text);
+  banner = hildon_note_new_information(GTK_WINDOW(parent), Text);
   gint retcode = gtk_dialog_run (GTK_DIALOG (banner));
   gtk_widget_destroy (banner);
   return;
 }
 
+void write_ua ( const char * ua )
+{
+	if (strlen(ua)>0) {
+		FILE *file = fopen ( _("/opt/HideUserAgent/UA.txt"), _("w") );
+
+		if ( file != NULL )
+		{
+			fputs(ua, file);
+			fclose ( file );
+		}
+	}
+}
+
+char * read_ua ( void )
+{
+	gchar *ua;
+	FILE *file = fopen ( _("/opt/HideUserAgent/UA.txt"), _("r") );
+
+	if ( file != NULL )
+	{
+		char line [ 256 ];
+
+		if ( fgets ( line, sizeof line, file ) != NULL )
+		{
+			ua = g_strdup(line);
+		}
+		fclose ( file );
+	}
+	return ua;
+}
+
+/* This displays a dialog box allowing the user to specify the useragent */
+void AskForUserAgent(GtkWidget *parent)
+{
+	GtkWidget *dialog, *Caption, *UaString;
+	gint response;
+	gchar *ua;
+
+	dialog = gtk_dialog_new_with_buttons(
+			_("Specify the User Agent to use"),
+			GTK_WINDOW(parent),
+			GTK_DIALOG_MODAL | GTK_DIALOG_NO_SEPARATOR,
+			GTK_STOCK_OK,
+			GTK_RESPONSE_OK,
+			GTK_STOCK_CANCEL,
+			GTK_RESPONSE_CANCEL,
+			NULL);
+
+	UaString = hildon_entry_new (HILDON_SIZE_AUTO);
+	ua=read_ua();
+	gtk_entry_set_text(UaString, ua);
+
+	Caption = hildon_caption_new (NULL, _("User Agent"), UaString, NULL, HILDON_CAPTION_MANDATORY);
+	gtk_container_add (GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), Caption);
+	gtk_widget_show_all (dialog);
+
+
+	/* Wait until user finishes the dialog. */
+	response = gtk_dialog_run(GTK_DIALOG(dialog));
+	if (response == GTK_RESPONSE_OK)
+	{
+		write_ua(gtk_entry_get_text (UaString));
+	}
+	/* Free the dialog (and it's children) */
+	gtk_widget_destroy(GTK_WIDGET(dialog));
+	/*g_free(ua);*/
+}
+
 osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activated)
 {
 	GtkWidget *dialog;
@@ -59,18 +125,18 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	GtkWidget *LabelStatus, *LabelText;
 
 	setlocale(LC_ALL, "");
-	bindtextdomain("hideuseragent", "/usr/share/locale");
-	bind_textdomain_codeset("hideuseragent", "UTF-8");
-	textdomain("hideuseragent");
+	bindtextdomain(_("hideuseragent"), _("/usr/share/locale"));
+	bind_textdomain_codeset(_("hideuseragent"), _("UTF-8"));
+	textdomain(_("hideuseragent"));
 
-	FILE* result = popen(N_("/opt/HideUserAgent/MicroBUserAgent.sh get"), N_("r"));
+	FILE* result = popen(_("/opt/HideUserAgent/MicroBUserAgent.sh get"), _("r"));
 	if (fgets(line, 8, result)==NULL) {
-		printf (N_("ERROR fgets\n"));
+		printf (_("ERROR fgets\n"));
 	}
 	pclose(result);
 
 	LabelStatus = gtk_label_new("");
-	if (!g_strcmp0(line, N_("default"))) {
+	if (!g_strcmp0(line, _("default"))) {
 		gtk_label_set_markup(GTK_LABEL(LabelStatus), _("<span color=\"red\">The user agent is not currently customized.</span>"));
 	} else {
 		gtk_label_set_markup(GTK_LABEL(LabelStatus), _("<span color=\"red\">The user agent is currently customized.</span>"));
@@ -79,13 +145,15 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	/* Create dialog with OK and Cancel buttons. Leave the separator out,
 	 * as we do not have any content. */
 	dialog = gtk_dialog_new_with_buttons(
-		_("Hide MicroB User Agent"),
+		_("Hide User Agent"),
 		GTK_WINDOW(data),
 		GTK_DIALOG_MODAL | GTK_DIALOG_NO_SEPARATOR,
 		_("Set"),
 		RESPONSE_SET,
 		_("Remove"),
 		RESPONSE_REMOVE,
+		_("User Agent"),
+		RESPONSE_UA,
 		NULL);
 
 	LabelText = gtk_label_new(_("Please choose whether you want to set or remove the customization of Maemo Browser's user agent."));
@@ -97,29 +165,35 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 
 	gtk_widget_show_all (dialog);
 
+	response=-1;
 	/* Wait until user finishes the dialog. */
-	response = gtk_dialog_run(GTK_DIALOG(dialog));
-	if (response == RESPONSE_SET)
-	{
-		/* This correspond to the set command */
-		res=system(N_("/opt/HideUserAgent/MicroBUserAgent.sh set"));
-		if (!res) {
-			displayresult(dialog, _("User agent successfully updated. Browser will be restarted."));
-		} else {
-			displayresult(dialog, _("Error during user agent update"));
-		}
-	}
-	else if (response == RESPONSE_REMOVE)
-	{
-		/* This is a remove command */
-		res=system(N_("/opt/HideUserAgent/MicroBUserAgent.sh remove"));
-		if (!res) {
-			displayresult(dialog, _("User agent successfully updated. Browser will be restarted."));
-		} else {
-			displayresult(dialog, _("Error during user agent update"));
-		}
-	}
+	while (response==-1) {
+		response = gtk_dialog_run(GTK_DIALOG(dialog));
 
+		if (response == RESPONSE_SET) {
+			/* This correspond to the set command */
+			res=system(_("/opt/HideUserAgent/MicroBUserAgent.sh set"));
+			if (!res) {
+				displayresult(dialog, _("User agent successfully updated. Browser will be restarted."));
+			} else {
+				displayresult(dialog, _("Error during user agent update"));
+			}
+		}
+		else if (response == RESPONSE_REMOVE) {
+			/* This is a remove command */
+			res=system(_("/opt/HideUserAgent/MicroBUserAgent.sh remove"));
+			if (!res) {
+				displayresult(dialog, _("User agent successfully updated. Browser will be restarted."));
+			} else {
+				displayresult(dialog, _("Error during user agent update"));
+			}
+		}
+		else if (response == RESPONSE_UA) {
+			/* This is the command to specify a useragent */
+			AskForUserAgent(dialog);
+			response = -1;
+		}
+	}
 	/* Free the dialog (and it's children) */
 	gtk_widget_destroy(GTK_WIDGET(dialog));
 	return OSSO_OK;
